summaryrefslogtreecommitdiff
path: root/deps/sysobj_early/include/util_edid.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/sysobj_early/include/util_edid.h')
-rw-r--r--deps/sysobj_early/include/util_edid.h17
1 files changed, 11 insertions, 6 deletions
diff --git a/deps/sysobj_early/include/util_edid.h b/deps/sysobj_early/include/util_edid.h
index 9714bfbb..4efee6b3 100644
--- a/deps/sysobj_early/include/util_edid.h
+++ b/deps/sysobj_early/include/util_edid.h
@@ -31,8 +31,8 @@ typedef struct {
float vert_freq_hz;
int is_interlaced;
int stereo_mode;
- int pixel_clock_khz;
- int src; /* 0: edid, 1: etb, 2: std, 3: dtd, 4: cea-dtd, ... */
+ uint64_t pixel_clock_khz;
+ int src; /* 0: edid, 1: etb, 2: std, 3: dtd, 4: cea-dtd, 5: svd ... */
uint64_t pixels; /* h*v: easier to compare */
char class_inch[6];
} edid_output;
@@ -48,6 +48,12 @@ struct edid_dtd {
edid_output out;
};
+struct edid_svd {
+ uint8_t v;
+ int is_native;
+ edid_output out;
+};
+
struct edid_cea_header {
uint8_t *ptr;
int type, len;
@@ -65,10 +71,6 @@ struct edid_cea_audio {
int max_kbps; /* formats 2-8 */
};
-struct edid_cea_video {
- struct edid_cea_header header;
-};
-
struct edid_cea_vendor_spec {
struct edid_cea_header header;
};
@@ -107,6 +109,9 @@ typedef struct {
int dtd_count;
struct edid_dtd *dtds;
+ int svd_count;
+ struct edid_svd *svds;
+
int cea_block_count;
struct edid_cea_block *cea_blocks;